@@ -17,12 +17,10 @@
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file globus_gsi_proxy_handle.c
- * @file Sam Meder, Sam Lang
- *
- * $RCSfile: globus_gsi_proxy_handle.c,v $
- * $Revision: 1.23 $
- * $Date: 2010/08/20 18:58:49 $
+ * @brief @brief GSI Proxy Handle
+ * @author Sam Meder, Sam Lang
  */
+#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
 
 #define GLOBUS_GSI_PROXY_HANDLE_MALLOC_ERROR(_LENGTH_) \
     globus_error_put(globus_error_wrap_errno_error( \
@@ -34,16 +32,19 @@
         __LINE__, \
         "Could not allocate enough memory: %d bytes", \
         _LENGTH_))
-#endif
 
 #include "globus_i_gsi_proxy.h"
 
+#if OPENSSL_VERSION_NUMBER < 0x0090801fL
+#define GT_D2I_DATA_CAST 
+#else
+#define GT_D2I_DATA_CAST (const unsigned char **)
+#endif
+
 /**
- * @name Initialize and Destroy
- */
-/*@{*/
-/**
+ * @brief Initialize Handle
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Initialize a GSI Proxy handle.
  *
  * Initialize a proxy handle which can be used in subsequent
@@ -204,15 +205,12 @@ globus_gsi_proxy_handle_destroy(
     return GLOBUS_SUCCESS;
 }
 /* globus_gsi_proxy_handle_destroy */
-/*@}*/
 
 
 /**
- * @name Get/Set Request
- */
-/*@{*/
-/**
+ * @brief Get Request
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Get the certificate request from a GSI Proxy handle.
  *
  * @param handle
@@ -273,6 +271,7 @@ globus_gsi_proxy_handle_get_req(
 /* globus_gsi_proxy_handle_get_req */
 
 /**
+ * @brief Set Request
  * Set the certificate request in a GSI Proxy handle.
  *
  * @param handle
@@ -329,15 +328,12 @@ globus_gsi_proxy_handle_set_req(
     return result;
 }
 /* globus_gsi_proxy_handle_set_req */
-/*@}*/
 
 
 /**
- * @name Get/Set Private Key
- */
-/*@{*/
-/**
+ * @brief Get/Set Private Key
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Get the private key from a GSI Proxy handle.
  *
  * @param handle
@@ -432,7 +428,7 @@ globus_gsi_proxy_handle_get_private_key(
     tmp = der_encoded;
     
     if(!d2i_PrivateKey(handle->proxy_key->type, proxy_key, 
-                       &tmp, length))
+                       GT_D2I_DATA_CAST &tmp, length))
     {
         GLOBUS_GSI_PROXY_OPENSSL_ERROR_RESULT(
             result,
@@ -536,7 +532,7 @@ globus_gsi_proxy_handle_set_private_key(
         tmp = der_encoded;
         
         if(!d2i_PrivateKey(proxy_key->type, &handle->proxy_key, 
-                           &tmp, length))
+                           GT_D2I_DATA_CAST &tmp, length))
         {
             GLOBUS_GSI_PROXY_OPENSSL_ERROR_RESULT(
                 result,
@@ -557,14 +553,11 @@ globus_gsi_proxy_handle_set_private_key(
     return result;
 }
 /* globus_gsi_proxy_handle_set_private_key */
-/*@}*/
 
 /**
- * @name Get/Set Proxy Type
- */
-/*@{*/
-/**
+ * @brief Get Proxy Type
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Determine the type of proxy that will be generated when using this handle. 
  *
  * @param handle
@@ -606,6 +599,9 @@ globus_gsi_proxy_handle_get_type(
 /* globus_gsi_proxy_handle_get_type */
 
 /**
+ * @brief Get Proxy Type
+ * @ingroup globus_gsi_proxy_handle
+ * @details
  * Set the type of proxy that will be generated when using this handle. Note
  * that this will have no effect when generating a proxy from a proxy. In that
  * case the generated proxy will inherit the type of the parent.
@@ -670,14 +666,11 @@ globus_gsi_proxy_handle_set_type(
     return result;
 }
 /* globus_gsi_proxy_handle_set_type */
-/*@}*/
 
 /**
- * @name Get/Set Policy
- */
-/*@{*/
-/**
+ * @brief Set Policy
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Set the policy to be used in the GSI Proxy handle.
  *
  * This function sets the policy to be used in the proxy cert
@@ -766,6 +759,9 @@ globus_gsi_proxy_handle_set_policy(
 /* globus_gsi_proxy_handle_set_policy */
 
 /**
+ * @brief Get Policy
+ * @ingroup globus_gsi_proxy_handle
+ * @details
  * Get the policy from the GSI Proxy handle.
  *
  * This function gets the policy that is being used in the 
@@ -823,29 +819,26 @@ globus_gsi_proxy_handle_get_policy(
     return result;
 }
 /* globus_gsi_proxy_handle_get_policy */
-/*@}*/
 
 /**
- * @name Get/Set X509 Extensions
+ * @brief Add X.509 Extensions
  * @ingroup globus_gsi_proxy_handle
- */
-/*@{*/
-/**
- * Add an X509 extension to the GSI Proxy handle to be added to certificate
+ * @details
+ * Add an X.509 extension to the GSI Proxy handle to be added to certificate
  *
- * This function adds a X509 extension to the proxy certificate.
+ * This function adds a X.509 extension to the proxy certificate.
  *
  * @param handle
  *        The handle for the proxy to which the extension should be added.
- * @param extension
+ * @param ext
  *        The extension to be added.
  *
  * @return
  *        GLOBUS_SUCCESS if the addition was successful, otherwise an
  *        error is returned.
  *
- * @see globus_gsi_proxy_hande_get_extensions()
- * @see globus_gsi_proxy_hande_set_extensions()
+ * @see globus_gsi_proxy_handle_get_extensions()
+ * @see globus_gsi_proxy_handle_set_extensions()
  */
 globus_result_t
 globus_gsi_proxy_handle_add_extension(
@@ -883,7 +876,7 @@ globus_gsi_proxy_handle_add_extension(
             GLOBUS_GSI_PROXY_OPENSSL_ERROR_RESULT(
                 result,
                 GLOBUS_GSI_PROXY_ERROR_WITH_HANDLE,
-                (_PCSL("Failed to allocation new X509 Extension stack: %s"), _function_name_));
+                (_PCSL("Failed to allocation new X.509 Extension stack: %s"), _function_name_));
             goto exit;
         }
     }
@@ -900,21 +893,24 @@ globus_gsi_proxy_handle_add_extension(
 /* globus_gsi_proxy_handle_add_extension */
 
 /**
- * Set the X509 extensions from a GSI Proxy handle
+ * @brief Set X.509 Extensions
+ * @ingroup globus_gsi_proxy_handle
+ * @details
+ * Set the X.509 extensions from a GSI Proxy handle
  *
- * This function sets the X509 extensions for a proxy certificate.
+ * This function sets the X.509 extensions for a proxy certificate.
  *
  * @param handle
  *        The handle for the proxy from which the extension should be set.
- * @param extensions
+ * @param exts
  *        The extensions to be set. Can be NULL to clear extensions.
  *
  * @return
  *        GLOBUS_SUCCESS if the addition was successful, otherwise an
  *        error is returned.
  *
- * @see globus_gsi_proxy_hande_add_extension()
- * @see globus_gsi_proxy_hande_get_extensions()
+ * @see globus_gsi_proxy_handle_add_extension()
+ * @see globus_gsi_proxy_handle_get_extensions()
  */
 globus_result_t
 globus_gsi_proxy_handle_set_extensions(
@@ -954,7 +950,7 @@ globus_gsi_proxy_handle_set_extensions(
             GLOBUS_GSI_PROXY_OPENSSL_ERROR_RESULT(
                 result,
                 GLOBUS_GSI_PROXY_ERROR_WITH_HANDLE,
-                (_PCSL("Failed to duplicate X509 Extension stack: %s"), _function_name_));
+                (_PCSL("Failed to duplicate X.509 Extension stack: %s"), _function_name_));
             goto exit;
         }
     }
@@ -969,14 +965,17 @@ globus_gsi_proxy_handle_set_extensions(
 /* globus_gsi_proxy_handle_set_extensions */
 
 /**
- * Get the X509 extensions from a GSI Proxy handle
+ * @brief Get X.509 Extensions
+ * @ingroup globus_gsi_proxy_handle
+ * @details
+ * Get the X.509 extensions from a GSI Proxy handle
  *
- * This function returns the X509 extensions from the proxy certificate.
+ * This function returns the X.509 extensions from the proxy certificate.
  *
  * @param handle
  *        The handle for the proxy from which the extensions should be
  *        retrieved.
- * @param extensions
+ * @param exts
  *        The variable to hold the extensions. The caller is responsible
  *        for freeing the extensions with sk_X509_EXTENSION_free()
  *        when they are done with them.
@@ -985,8 +984,8 @@ globus_gsi_proxy_handle_set_extensions(
  *        GLOBUS_SUCCESS if the retrieval was successful, otherwise an
  *        error is returned.
  *
- * @see globus_gsi_proxy_hande_add_extension()
- * @see globus_gsi_proxy_hande_set_extensions()
+ * @see globus_gsi_proxy_handle_add_extension()
+ * @see globus_gsi_proxy_handle_set_extensions()
  */
 globus_result_t
 globus_gsi_proxy_handle_get_extensions(
@@ -1022,7 +1021,7 @@ globus_gsi_proxy_handle_get_extensions(
         GLOBUS_GSI_PROXY_OPENSSL_ERROR_RESULT(
             result,
             GLOBUS_GSI_PROXY_ERROR_WITH_HANDLE,
-            (_PCSL("Failed to duplicate X509 Extension stack: %s"), _function_name_));
+            (_PCSL("Failed to duplicate X.509 Extension stack: %s"), _function_name_));
         goto exit;
     }
 
@@ -1034,14 +1033,11 @@ globus_gsi_proxy_handle_get_extensions(
 }
 
 /* globus_gsi_proxy_handle_get_extensions */
-/*@}*/
 
 /**
- * @name Get/Set Path Length
- */
-/*@{*/
-/**
+ * @brief Set Path Length
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Set the path length to be used in the GSI Proxy handle.
  *
  * This function sets the path length to be used in the proxy
@@ -1097,6 +1093,9 @@ globus_gsi_proxy_handle_set_pathlen(
 /* globus_gsi_proxy_handle_set_pathlen */
 
 /**
+ * @brief Get Path Length
+ * @ingroup globus_gsi_proxy_handle
+ * @details
  * Get the path length from the GSI Proxy handle.
  *
  * This function gets the path length that is being used in the 
@@ -1140,15 +1139,11 @@ globus_gsi_proxy_handle_get_pathlen(
     return result;
 }
 /* globus_gsi_proxy_handle_get_pathlen */
-/*@}*/
-
 
 /**
- * @name Get/Set Time Valid
- */
-/* @{ */
-/**
+ * @brief Get Time Valid
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Get the validity time of the proxy
  *
  * @param handle
@@ -1189,6 +1184,9 @@ globus_gsi_proxy_handle_get_time_valid(
 /* globus_gsi_proxy_handle_get_time_valid */
 
 /**
+ * @brief Set Time Valid
+ * @ingroup globus_gsi_proxy_handle
+ * @details
  * Set the validity time of the proxy
  *
  * @param handle
@@ -1228,14 +1226,11 @@ globus_gsi_proxy_handle_set_time_valid(
     return result;
 }
 /* globus_gsi_proxy_handle_set_time_valid */
-/*@}*/
 
 /**
- * @name Clear Cert Info
- */
-/*@{*/
-/**
+ * @brief Clear Cert Info
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Clear the proxy cert info extension stored in the GSI Proxy handle.
  *
  * This function clears proxy cert info extension related setting in
@@ -1285,14 +1280,11 @@ globus_gsi_proxy_handle_clear_cert_info(
     return result;
 }
 /* globus_gsi_proxy_handle_clear_cert_info */
-/*@}*/
 
 /**
- * @name Get/Set Cert Info
- */
-/*@{*/
-/**
+ * @brief Get Cert Info
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Get the proxy cert info extension stored in the GSI Proxy handle.
  *
  * This function retrieves the proxy cert info extension from the GSI Proxy
@@ -1363,6 +1355,9 @@ globus_gsi_proxy_handle_get_proxy_cert_info(
 /* globus_gsi_proxy_handle_get_proxy_cert_info */
 
 /**
+ * @brief Set Cert Info
+ * @ingroup globus_gsi_proxy_handle
+ * @details
  * Set the proxy cert info extension stored in the GSI Proxy handle.
  *
  * This function sets the proxy cert info extension in the GSI Proxy handle.
@@ -1371,11 +1366,9 @@ globus_gsi_proxy_handle_get_proxy_cert_info(
  *        The handle for which to set the proxy cert info extension.
  * @param pci
  *        The proxy cert info extension to set.
- * @return
- *        GLOBUS_SUCCESS upon success
- *        GLOBUS_GSI_PROXY_ERROR_WITH_HANDLE if handle is invalid
- *        GLOBUS_GSI_PROXY_ERROR_WITH_PROXYCERTINFO if the pci
- *        pointer is invalid or if the set failed.
+ * @retval GLOBUS_SUCCESS Success
+ * @retval GLOBUS_GSI_PROXY_ERROR_WITH_HANDLE Handle is invalid
+ * @retval GLOBUS_GSI_PROXY_ERROR_WITH_PROXYCERTINFO pci pointer is invalid or if the set failed.
  */
 globus_result_t
 globus_gsi_proxy_handle_set_proxy_cert_info(
@@ -1421,14 +1414,11 @@ globus_gsi_proxy_handle_set_proxy_cert_info(
     return result;
 }
 /* globus_gsi_proxy_handle_set_proxy_cert_info */
-/*@}*/
 
 /**
- * @name Get Signing Algorithm
- */
-/* @{ */
-/**
+ * @brief Get Signing Algorithm
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Get the signing algorithm used to sign the proxy cert request
  *
  * @param handle
@@ -1436,10 +1426,9 @@ globus_gsi_proxy_handle_set_proxy_cert_info(
  * @param signing_algorithm
  *        signing algorithm of the proxy handle
  * 
- * @result
+ * @retval
  *        GLOBUS_SUCCESS unless an error occurred, in which case, 
  *        a globus error object ID is returned
- *        GLOBUS_SUCCESS
  */
 globus_result_t
 globus_gsi_proxy_handle_get_signing_algorithm(
@@ -1465,14 +1454,11 @@ globus_gsi_proxy_handle_get_signing_algorithm(
     GLOBUS_I_GSI_PROXY_DEBUG_EXIT;
     return result;
 }
-/* @} */
 
 /**
- * @name Get Key Bits
- */
-/* @{ */
-/**
+ * @brief Get Key Bits
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Get the key bits used for the pub/private key pair of the proxy
  *
  * @param handle
@@ -1508,14 +1494,11 @@ globus_gsi_proxy_handle_get_keybits(
     GLOBUS_I_GSI_PROXY_DEBUG_EXIT;
     return result;
 }
-/* @} */
 
 /**
- * @name Get Init Prime
- */
-/* @{ */
-/**
+ * @brief Get Init Prime
  * @ingroup globus_gsi_proxy_handle 
+ * @details
  * Get the init prime of the proxy handle
  *
  * @param handle
@@ -1551,15 +1534,12 @@ globus_gsi_proxy_handle_get_init_prime(
     GLOBUS_I_GSI_PROXY_DEBUG_EXIT;
     return result;
 }
-/* @} */
 
 
 /**
- * @name Get Clock Skew
- */
-/* @{ */
-/**
+ * @brief Get Clock Skew
  * @ingroup globus_gsi_proxy_handle  
+ * @details
  * Get the clock skew of the proxy handle
  *
  * @param handle
@@ -1596,14 +1576,11 @@ globus_gsi_proxy_handle_get_clock_skew_allowable(
     GLOBUS_I_GSI_PROXY_DEBUG_EXIT;
     return result;
 }
-/* @} */
 
 /**
- * @name Get Callback for Creating Keys
- */
-/* @{ */
-/**
+ * @brief Get Callback for Creating Keys
  * @ingroup globus_gsi_proxy_handle 
+ * @details
  * Get the callback for creating the public/private key pair
  *
  * @param handle
@@ -1638,15 +1615,12 @@ globus_gsi_proxy_handle_get_key_gen_callback(
     GLOBUS_I_GSI_PROXY_DEBUG_EXIT;
     return result;
 } 
-/* @} */        
 
 
 /**
- * @name Get/Set Proxy Common Name
- */
-/*@{*/
-/**
+ * @brief Get/Set Proxy Common Name
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Get the proxy common name stored in the GSI Proxy handle.
  *
  * This function retrieves the proxy common name from the GSI Proxy
@@ -1768,15 +1742,12 @@ globus_gsi_proxy_handle_set_common_name(
     return result;
 }
 /* globus_gsi_proxy_handle_set_common_name */
-/*@}*/
 
 
 /**
- * @name Set/Check Proxy Is Limited
- */
-/* @{ */
-/**
+ * @brief Set/Check Proxy Is Limited
  * @ingroup globus_gsi_proxy_handle
+ * @details
  * Set the limited proxy flag on the proxy handle
  *
  * @param handle
@@ -1858,7 +1829,7 @@ globus_gsi_proxy_handle_set_is_limited(
 
 
 /**
- * Check to see if the proxy is a limited proxy 
+ * Check to see  the proxy is a limited proxy 
  *
  * @param handle
  *        the proxy handle to check
@@ -1884,4 +1855,3 @@ globus_gsi_proxy_is_limited(
     GLOBUS_I_GSI_PROXY_DEBUG_EXIT;
     return GLOBUS_SUCCESS;
 }
-/* @} */
